==> uikit-3.0.0-rc.19.tgz: package/src/js/mixin/slider-autoplay.js <==
import {pointerDown} from 'uikit-util';

export default {

    props: {
        autoplay: Boolean,
        autoplayInterval: Number,
        pauseOnHover: Boolean
    },

    data: {
        autoplay: false,
        autoplayInterval: 7000,
        pauseOnHover: true
    },

    connected() {
        this.startAutoplay();
    },

    disconnected() {
        this.stopAutoplay();
    },

    events: [

        {

            name: 'visibilitychange',

            el: document,

            handler() {
                if (document.hidden) {
                    this.stopAutoplay();
                } else {
                    this.startAutoplay();
                }
            }

        },

        {

            name: pointerDown,
            handler: 'stopAutoplay'

        },

        {

            name: 'mouseenter',

            filter() {
                return this.autoplay;
            },

            handler() {
                this.isHovering = true;
            }

        },

        {

            name: 'mouseleave',

            filter() {
                return this.autoplay;
            },

            handler() {
                this.isHovering = false;
            }

        }

    ],

    methods: {

        startAutoplay() {

            this.stopAutoplay();

            if (this.autoplay) {
                this.interval = setInterval(
                    () => !(this.isHovering && this.pauseOnHover) && !this.stack.length && this.show('next'),
                    this.autoplayInterval
                );
            }

        },

        stopAutoplay() {
            if (this.interval) {
                clearInterval(this.interval);
            }
        }

    }

};

==> uikit-3.1.0.tgz: package/src/js/mixin/slider-autoplay.js <==
import {attr, within} from 'uikit-util';

export default {

    props: {
        autoplay: Boolean,
        autoplayInterval: Number,
        pauseOnHover: Boolean
    },

    data: {
        autoplay: false,
        autoplayInterval: 7000,
        pauseOnHover: true
    },

    connected() {
        this.autoplay && this.startAutoplay();
    },

    disconnected() {
        this.stopAutoplay();
    },

    update() {
        attr(this.slides, 'tabindex', '-1');
    },

    events: [

        {

            name: 'visibilitychange',

            el: document,

            filter() {
                return this.autoplay;
            },

            handler() {
                if (document.hidden) {
                    this.stopAutoplay();
                } else {
                    this.startAutoplay();
                }
            }

        },

        {

            name: 'mouseenter',

            filter() {
                return this.autoplay && this.pauseOnHover;
            },

            handler() {
                this.isHovering = true;
            }

        },

        {

            name: 'mouseleave',

            filter() {
                return this.autoplay && this.pauseOnHover;
            },

            handler() {
                this.isHovering = false;
            }

        }

    ],

    methods: {

        startAutoplay() {

            this.stopAutoplay();

            this.interval = setInterval(
                () => !within(document.activeElement, this.$el)
                    && !this.isHovering
                    && !this.stack.length
                    && this.show('next'),
                this.autoplayInterval
            );

        },

        stopAutoplay() {
            this.interval && clearInterval(this.interval);
        }

    }

};
